@@ -13,20 +13,24 @@ ntwd_get_id <- function(id, .verbose) {
       "terraced", "flats", "semi_det", "detached",
       "aftb_ind", "aftb_hper")
 
+  if (length(id) > 1) {
+    stop("trying to access multiple files", call. = FALSE)
+  }
   if (!(id %in% id_categories)) {
     stop("`id` is not valid, see ?ntwd_dataset.", call. = FALSE)
   }
-  switch(id,
-     monthly = ntwd_get_monthly(.access_info = .verbose),
-     quarterly = ntwd_get_quarterly(.access_info = .verbose),
-     since_1952 = ntwd_get_since_1952(.access_info = .verbose),
-     inflation_adjusted = ntwd_get_inflation_adjusted(.access_info = .verbose),
-     regional = ntwd_get_generic("all_prop", .access_info = .verbose),
-     seasonal_regional = ntwd_get_seasonal_regional(.access_info = .verbose),
-     not_new_prop = ntwd_get_not_new_prop(.access_info = .verbose),
-     aftb_ind = ntwd_get_aftb_ind(.access_info = .verbose),
-     aftb_hper = ntwd_get_aftb_hper(.access_info = .verbose),
-     ntwd_get_generic(id, .access_info = .verbose)
+  switch(
+    id,
+    monthly = ntwd_get_monthly(.access_info = .verbose),
+    quarterly = ntwd_get_quarterly(.access_info = .verbose),
+    since_1952 = ntwd_get_since_1952(.access_info = .verbose),
+    inflation_adjusted = ntwd_get_inflation_adjusted(.access_info = .verbose),
+    regional = ntwd_get_generic("all_prop", .access_info = .verbose),
+    seasonal_regional = ntwd_get_seasonal_regional(.access_info = .verbose),
+    not_new_prop = ntwd_get_not_new_prop(.access_info = .verbose),
+    aftb_ind = ntwd_get_aftb_ind(.access_info = .verbose),
+    aftb_hper = ntwd_get_aftb_hper(.access_info = .verbose),
+    ntwd_get_generic(id, .access_info = .verbose)
   )
 }
 
@@ -40,7 +44,7 @@ ntwd_get_id <- function(id, .verbose) {
 #'
 #' @details Not all objects contain metadata
 #'
-#' @return A chracter vector.
+#' @return A character vector.
 #'
 #' @export
 #'
